==> zarf-v0.28.3.tar.gz: zarf-0.28.3/src/internal/packager/sbom/viewer.go <==
// SPDX-License-Identifier: Apache-2.0
// SPDX-FileCopyrightText: 2021-Present The Zarf Authors

// Package sbom contains tools for generating SBOMs.
package sbom

import (
	"encoding/json"
	"fmt"
	"html/template"

	"github.com/defenseunicorns/zarf/src/types"
)

func (b *Builder) createSBOMViewerAsset(identifier string, jsonData []byte) error {
	filename := fmt.Sprintf("sbom-viewer-%s.html", b.getNormalizedFileName(identifier))
	return b.createSBOMHTML(filename, "viewer/template.gohtml", jsonData)
}

func (b *Builder) createSBOMCompareAsset() error {
	return b.createSBOMHTML("compare.html", "viewer/compare.gohtml", []byte{})
}

func (b *Builder) createSBOMHTML(filename string, goTemplate string, jsonData []byte) error {
	// Create the sbom viewer file for the image
	sbomViewerFile, err := b.createSBOMFile(filename)
	if err != nil {
		return err
	}

	defer sbomViewerFile.Close()

	// Create the sbomviewer template data
	tplData := struct {
		ThemeCSS  template.CSS
		ViewerCSS template.CSS
		List      template.JS
		Data      template.JS
		LibraryJS template.JS
		CommonJS  template.JS
		ViewerJS  template.JS
		CompareJS template.JS
	}{
		ThemeCSS:  b.loadFileCSS("theme.css"),
		ViewerCSS: b.loadFileCSS("styles.css"),
		List:      template.JS(b.jsonList),
		Data:      template.JS(jsonData),
		LibraryJS: b.loadFileJS("library.js"),
		CommonJS:  b.loadFileJS("common.js"),
		ViewerJS:  b.loadFileJS("viewer.js"),
		CompareJS: b.loadFileJS("compare.js"),
	}

	// Render the sbomviewer template
	tpl, err := template.ParseFS(viewerAssets, goTemplate)
	if err != nil {
		return err
	}

	// Write the sbomviewer template to disk
	return tpl.Execute(sbomViewerFile, tplData)
}

func (b *Builder) loadFileCSS(name string) template.CSS {
	data, _ := viewerAssets.ReadFile("viewer/" + name)
	return template.CSS(data)
}

func (b *Builder) loadFileJS(name string) template.JS {
	data, _ := viewerAssets.ReadFile("viewer/" + name)
	return template.JS(data)
}

// This could be optimized, but loop over all the images and components to create a list of json files.
func (b *Builder) generateJSONList(componentToFiles map[string]*types.ComponentSBOM, imgList []string) ([]byte, error) {
	var jsonList []string

	for _, tag := range imgList {
		normalized := b.getNormalizedFileName(tag)
		jsonList = append(jsonList, normalized)
	}

	for component := range componentToFiles {
		normalized := b.getNormalizedFileName(fmt.Sprintf("%s%s", componentPrefix, component))
		jsonList = append(jsonList, normalized)
	}

	return json.Marshal(jsonList)
}

==> zarf-v0.32.1.tar.gz: zarf-0.32.1/src/internal/packager/sbom/viewer.go <==
// SPDX-License-Identifier: Apache-2.0
// SPDX-FileCopyrightText: 2021-Present The Zarf Authors

// Package sbom contains tools for generating SBOMs.
package sbom

import (
	"encoding/json"
	"fmt"
	"html/template"

	"github.com/defenseunicorns/zarf/src/pkg/layout"
	"github.com/defenseunicorns/zarf/src/pkg/transform"
)

func (b *Builder) createSBOMViewerAsset(identifier string, jsonData []byte) error {
	filename := fmt.Sprintf("sbom-viewer-%s.html", b.getNormalizedFileName(identifier))
	return b.createSBOMHTML(filename, "viewer/template.gohtml", jsonData)
}

func (b *Builder) createSBOMCompareAsset() error {
	return b.createSBOMHTML("compare.html", "viewer/compare.gohtml", []byte{})
}

func (b *Builder) createSBOMHTML(filename string, goTemplate string, jsonData []byte) error {
	// Create the sbom viewer file for the image
	sbomViewerFile, err := b.createSBOMFile(filename)
	if err != nil {
		return err
	}

	defer sbomViewerFile.Close()

	// Create the sbomviewer template data
	tplData := struct {
		ThemeCSS  template.CSS
		ViewerCSS template.CSS
		List      template.JS
		Data      template.JS
		LibraryJS template.JS
		CommonJS  template.JS
		ViewerJS  template.JS
		CompareJS template.JS
	}{
		ThemeCSS:  b.loadFileCSS("theme.css"),
		ViewerCSS: b.loadFileCSS("styles.css"),
		List:      template.JS(b.jsonList),
		Data:      template.JS(jsonData),
		LibraryJS: b.loadFileJS("library.js"),
		CommonJS:  b.loadFileJS("common.js"),
		ViewerJS:  b.loadFileJS("viewer.js"),
		CompareJS: b.loadFileJS("compare.js"),
	}

	// Render the sbomviewer template
	tpl, err := template.ParseFS(viewerAssets, goTemplate)
	if err != nil {
		return err
	}

	// Write the sbomviewer template to disk
	return tpl.Execute(sbomViewerFile, tplData)
}

func (b *Builder) loadFileCSS(name string) template.CSS {
	data, _ := viewerAssets.ReadFile("viewer/" + name)
	return template.CSS(data)
}

func (b *Builder) loadFileJS(name string) template.JS {
	data, _ := viewerAssets.ReadFile("viewer/" + name)
	return template.JS(data)
}

// This could be optimized, but loop over all the images and components to create a list of json files.
func (b *Builder) generateJSONList(componentToFiles map[string]*layout.ComponentSBOM, imageList []transform.Image) ([]byte, error) {
	var jsonList []string

	for _, refInfo := range imageList {
		normalized := b.getNormalizedFileName(refInfo.Reference)
		jsonList = append(jsonList, normalized)
	}

	for component := range componentToFiles {
		normalized := b.getNormalizedFileName(fmt.Sprintf("%s%s", componentPrefix, component))
		jsonList = append(jsonList, normalized)
	}

	return json.Marshal(jsonList)
}
